import { __rest } from 'tslib';
import * as i0 from '@angular/core';
import { InjectionToken, Pipe, Optional, Inject, NgModule } from '@angular/core';

/**
 * Set the locale(s) for all Intl Pipes. If not specified, the user language specified in the browser will be used. If
 * specified, it needs to be a string with a BCP 47 language tag, or an array of such strings.
 */
const INTL_LOCALES = new InjectionToken('IntlLocales');

const INTL_COUNTRY_PIPE_DEFAULT_OPTIONS = new InjectionToken('IntlCountryPipeDefaultOptions');

class IntlCountryPipe {
    constructor(locale, defaultOptions) {
        this.locale = locale;
        this.defaultOptions = defaultOptions;
    }
    transform(value, options) {
        var _a, _b;
        if (!value) {
            return null;
        }
        const _c = options !== null && options !== void 0 ? options : {}, { locale } = _c, intlOptions = __rest(_c, ["locale"]);
        try {
            return (_b = new Intl.DisplayNames((_a = locale !== null && locale !== void 0 ? locale : this.locale) !== null && _a !== void 0 ? _a : undefined, Object.assign(Object.assign(Object.assign({}, this.defaultOptions), intlOptions), { type: 'region' })).of(value)) !== null && _b !== void 0 ? _b : null;
        }
        catch (e) {
            console.error('Error while transforming the country', e);
            return null;
        }
    }
}
IntlCountryPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.0", ngImport: i0, type: IntlCountryPipe, deps: [{ token: INTL_LOCALES, optional: true }, { token: INTL_COUNTRY_PIPE_DEFAULT_OPTIONS, optional: true }], target: i0.ɵɵFactoryTarget.Pipe });
IntlCountryPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "15.2.0", ngImport: i0, type: IntlCountryPipe, isStandalone: true, name: "intlCountry" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.0", ngImport: i0, type: IntlCountryPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'intlCountry',
                    standalone: true,
                }]
        }], ctorParameters: function () {
        return [{ type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [INTL_LOCALES]
                    }] }, { type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [INTL_COUNTRY_PIPE_DEFAULT_OPTIONS]
                    }] }];
    } });

const INTL_CURRENCY_PIPE_DEFAULT_OPTIONS = new InjectionToken('IntlCurrencyPipeDefaultOptions');

const getNumericValue = (value) => {
    if (typeof value === 'number') {
        return value;
    }
    if (isNaN(Number(value) - parseFloat(value))) {
        throw new Error(`${value} is not a number!`);
    }
    return Number(value);
};

class IntlCurrencyPipe {
    constructor(locale, defaultOptions) {
        this.locale = locale;
        this.defaultOptions = defaultOptions;
    }
    transform(value, currency, options) {
        var _a;
        if (typeof value !== 'number' && !value) {
            return null;
        }
        const numericValue = getNumericValue(value);
        const _b = options !== null && options !== void 0 ? options : {}, { locale } = _b, intlOptions = __rest(_b, ["locale"]);
        try {
            return new Intl.NumberFormat((_a = locale !== null && locale !== void 0 ? locale : this.locale) !== null && _a !== void 0 ? _a : undefined, Object.assign(Object.assign(Object.assign({}, this.defaultOptions), intlOptions), { currency, style: 'currency' })).format(numericValue);
        }
        catch (e) {
            console.error('Error while transforming the currency', e);
            return null;
        }
    }
}
IntlCurrencyPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.0", ngImport: i0, type: IntlCurrencyPipe, deps: [{ token: INTL_LOCALES, optional: true }, { token: INTL_CURRENCY_PIPE_DEFAULT_OPTIONS, optional: true }], target: i0.ɵɵFactoryTarget.Pipe });
IntlCurrencyPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "15.2.0", ngImport: i0, type: IntlCurrencyPipe, isStandalone: true, name: "intlCurrency" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.0", ngImport: i0, type: IntlCurrencyPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'intlCurrency',
                    standalone: true,
                }]
        }], ctorParameters: function () {
        return [{ type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [INTL_LOCALES]
                    }] }, { type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [INTL_CURRENCY_PIPE_DEFAULT_OPTIONS]
                    }] }];
    } });

const INTL_DATE_PIPE_DEFAULT_OPTIONS = new InjectionToken('IntlDatePipeDefaultOptions');

class IntlDatePipe {
    constructor(locale, defaultOptions) {
        this.locale = locale;
        this.defaultOptions = defaultOptions;
    }
    transform(value, options) {
        var _a;
        if (typeof value !== 'number' && !value) {
            return null;
        }
        const date = new Date(value);
        if (isNaN(date.getTime())) {
            return null;
        }
        const _b = options !== null && options !== void 0 ? options : {}, { locale } = _b, intlOptions = __rest(_b, ["locale"]);
        try {
            return new Intl.DateTimeFormat((_a = locale !== null && locale !== void 0 ? locale : this.locale) !== null && _a !== void 0 ? _a : undefined, Object.assign(Object.assign({}, this.defaultOptions), intlOptions)).format(date);
        }
        catch (e) {
            console.error('Error while transforming the date', e);
            return null;
        }
    }
}
IntlDatePipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.0", ngImport: i0, type: IntlDatePipe, deps: [{ token: INTL_LOCALES, optional: true }, { token: INTL_DATE_PIPE_DEFAULT_OPTIONS, optional: true }], target: i0.ɵɵFactoryTarget.Pipe });
IntlDatePipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "15.2.0", ngImport: i0, type: IntlDatePipe, isStandalone: true, name: "intlDate" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.0", ngImport: i0, type: IntlDatePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'intlDate',
                    standalone: true,
                }]
        }], ctorParameters: function () {
        return [{ type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [INTL_LOCALES]
                    }] }, { type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [INTL_DATE_PIPE_DEFAULT_OPTIONS]
                    }] }];
    } });

const INTL_DECIMAL_PIPE_DEFAULT_OPTIONS = new InjectionToken('IntlDecimalPipeDefaultOptions');

class IntlDecimalPipe {
    constructor(locale, defaultOptions) {
        this.locale = locale;
        this.defaultOptions = defaultOptions;
    }
    transform(value, options) {
        var _a;
        if (typeof value !== 'number' && !value) {
            return null;
        }
        const numericValue = getNumericValue(value);
        const _b = options !== null && options !== void 0 ? options : {}, { locale } = _b, intlOptions = __rest(_b, ["locale"]);
        try {
            return new Intl.NumberFormat((_a = locale !== null && locale !== void 0 ? locale : this.locale) !== null && _a !== void 0 ? _a : undefined, Object.assign(Object.assign(Object.assign({}, this.defaultOptions), intlOptions), { style: 'decimal' })).format(numericValue);
        }
        catch (e) {
            console.error('Error while transforming the decimal number', e);
            return null;
        }
    }
}
IntlDecimalPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.0", ngImport: i0, type: IntlDecimalPipe, deps: [{ token: INTL_LOCALES, optional: true }, { token: INTL_DECIMAL_PIPE_DEFAULT_OPTIONS, optional: true }], target: i0.ɵɵFactoryTarget.Pipe });
IntlDecimalPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "15.2.0", ngImport: i0, type: IntlDecimalPipe, isStandalone: true, name: "intlDecimal" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.0", ngImport: i0, type: IntlDecimalPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'intlDecimal',
                    standalone: true,
                }]
        }], ctorParameters: function () {
        return [{ type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [INTL_LOCALES]
                    }] }, { type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [INTL_DECIMAL_PIPE_DEFAULT_OPTIONS]
                    }] }];
    } });

const INTL_LANGUAGE_PIPE_DEFAULT_OPTIONS = new InjectionToken('IntlLanguagePipeDefaultOptions');

class IntlLanguagePipe {
    constructor(locale, defaultOptions) {
        this.locale = locale;
        this.defaultOptions = defaultOptions;
    }
    transform(value, options) {
        var _a, _b;
        if (!value) {
            return null;
        }
        const _c = options !== null && options !== void 0 ? options : {}, { locale } = _c, intlOptions = __rest(_c, ["locale"]);
        try {
            return (_b = new Intl.DisplayNames((_a = locale !== null && locale !== void 0 ? locale : this.locale) !== null && _a !== void 0 ? _a : undefined, Object.assign(Object.assign(Object.assign({}, this.defaultOptions), intlOptions), { type: 'language' })).of(value)) !== null && _b !== void 0 ? _b : null;
        }
        catch (e) {
            console.error('Error while transforming the language', e);
            return null;
        }
    }
}
IntlLanguagePipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.0", ngImport: i0, type: IntlLanguagePipe, deps: [{ token: INTL_LOCALES, optional: true }, { token: INTL_LANGUAGE_PIPE_DEFAULT_OPTIONS, optional: true }], target: i0.ɵɵFactoryTarget.Pipe });
IntlLanguagePipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "15.2.0", ngImport: i0, type: IntlLanguagePipe, isStandalone: true, name: "intlLanguage" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.0", ngImport: i0, type: IntlLanguagePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'intlLanguage',
                    standalone: true,
                }]
        }], ctorParameters: function () {
        return [{ type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [INTL_LOCALES]
                    }] }, { type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [INTL_LANGUAGE_PIPE_DEFAULT_OPTIONS]
                    }] }];
    } });

const INTL_PERCENT_PIPE_DEFAULT_OPTIONS = new InjectionToken('IntlPercentPipeDefaultOptions');

class IntlPercentPipe {
    constructor(locale, defaultOptions) {
        this.locale = locale;
        this.defaultOptions = defaultOptions;
    }
    transform(value, options) {
        var _a;
        if (typeof value !== 'number' && !value) {
            return null;
        }
        const numericValue = getNumericValue(value);
        const _b = options !== null && options !== void 0 ? options : {}, { locale } = _b, intlOptions = __rest(_b, ["locale"]);
        try {
            return new Intl.NumberFormat((_a = locale !== null && locale !== void 0 ? locale : this.locale) !== null && _a !== void 0 ? _a : undefined, Object.assign(Object.assign(Object.assign({}, this.defaultOptions), intlOptions), { style: 'percent' })).format(numericValue);
        }
        catch (e) {
            console.error('Error while transforming the percent value', e);
            return null;
        }
    }
}
IntlPercentPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.0", ngImport: i0, type: IntlPercentPipe, deps: [{ token: INTL_LOCALES, optional: true }, { token: INTL_PERCENT_PIPE_DEFAULT_OPTIONS, optional: true }], target: i0.ɵɵFactoryTarget.Pipe });
IntlPercentPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "15.2.0", ngImport: i0, type: IntlPercentPipe, isStandalone: true, name: "intlPercent" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.0", ngImport: i0, type: IntlPercentPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'intlPercent',
                    standalone: true,
                }]
        }], ctorParameters: function () {
        return [{ type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [INTL_LOCALES]
                    }] }, { type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [INTL_PERCENT_PIPE_DEFAULT_OPTIONS]
                    }] }];
    } });

const INTL_UNIT_PIPE_DEFAULT_OPTIONS = new InjectionToken('IntlUnitPipeDefaultOptions');

class IntlUnitPipe {
    constructor(locale, defaultOptions) {
        this.locale = locale;
        this.defaultOptions = defaultOptions;
    }
    transform(value, unit, options) {
        var _a;
        if (typeof value !== 'number' && !value) {
            return null;
        }
        const numericValue = getNumericValue(value);
        const _b = options !== null && options !== void 0 ? options : {}, { locale } = _b, intlOptions = __rest(_b, ["locale"]);
        try {
            return new Intl.NumberFormat((_a = locale !== null && locale !== void 0 ? locale : this.locale) !== null && _a !== void 0 ? _a : undefined, Object.assign(Object.assign(Object.assign({}, this.defaultOptions), intlOptions), { unit, style: 'unit' })).format(numericValue);
        }
        catch (e) {
            console.error('Error while transforming the unit value', e);
            return null;
        }
    }
}
IntlUnitPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.0", ngImport: i0, type: IntlUnitPipe, deps: [{ token: INTL_LOCALES, optional: true }, { token: INTL_UNIT_PIPE_DEFAULT_OPTIONS, optional: true }], target: i0.ɵɵFactoryTarget.Pipe });
IntlUnitPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "15.2.0", ngImport: i0, type: IntlUnitPipe, isStandalone: true, name: "intlUnit" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.0", ngImport: i0, type: IntlUnitPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'intlUnit',
                    standalone: true,
                }]
        }], ctorParameters: function () {
        return [{ type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [INTL_LOCALES]
                    }] }, { type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [INTL_UNIT_PIPE_DEFAULT_OPTIONS]
                    }] }];
    } });

const INTL_LIST_PIPE_DEFAULT_OPTIONS = new InjectionToken('IntlListPipeDefaultOptions');

class IntlListPipe {
    constructor(locale, defaultOptions) {
        this.locale = locale;
        this.defaultOptions = defaultOptions;
    }
    transform(value, options) {
        var _a;
        if (!value) {
            return null;
        }
        const _b = options !== null && options !== void 0 ? options : {}, { locale } = _b, intlOptions = __rest(_b, ["locale"]);
        try {
            return new Intl.ListFormat((_a = locale !== null && locale !== void 0 ? locale : this.locale) !== null && _a !== void 0 ? _a : undefined, Object.assign(Object.assign({}, this.defaultOptions), intlOptions)).format(value);
        }
        catch (e) {
            console.error('Error while transforming the list', e);
            return null;
        }
    }
}
IntlListPipe.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.0", ngImport: i0, type: IntlListPipe, deps: [{ token: INTL_LOCALES, optional: true }, { token: INTL_LIST_PIPE_DEFAULT_OPTIONS, optional: true }], target: i0.ɵɵFactoryTarget.Pipe });
IntlListPipe.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "15.2.0", ngImport: i0, type: IntlListPipe, isStandalone: true, name: "intlList" });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.0", ngImport: i0, type: IntlListPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'intlList',
                    standalone: true,
                }]
        }], ctorParameters: function () {
        return [{ type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [INTL_LOCALES]
                    }] }, { type: undefined, decorators: [{
                        type: Optional
                    }, {
                        type: Inject,
                        args: [INTL_LIST_PIPE_DEFAULT_OPTIONS]
                    }] }];
    } });

class IntlModule {
}
IntlModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "15.2.0", ngImport: i0, type: IntlModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
IntlModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "15.2.0", ngImport: i0, type: IntlModule, imports: [IntlDatePipe,
        IntlLanguagePipe,
        IntlDecimalPipe,
        IntlPercentPipe,
        IntlCurrencyPipe,
        IntlCountryPipe,
        IntlUnitPipe,
        IntlListPipe], exports: [IntlDatePipe,
        IntlLanguagePipe,
        IntlDecimalPipe,
        IntlPercentPipe,
        IntlCurrencyPipe,
        IntlCountryPipe,
        IntlUnitPipe,
        IntlListPipe] });
IntlModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "15.2.0", ngImport: i0, type: IntlModule });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "15.2.0", ngImport: i0, type: IntlModule, decorators: [{
            type: NgModule,
            args: [{
                    imports: [
                        IntlDatePipe,
                        IntlLanguagePipe,
                        IntlDecimalPipe,
                        IntlPercentPipe,
                        IntlCurrencyPipe,
                        IntlCountryPipe,
                        IntlUnitPipe,
                        IntlListPipe,
                    ],
                    exports: [
                        IntlDatePipe,
                        IntlLanguagePipe,
                        IntlDecimalPipe,
                        IntlPercentPipe,
                        IntlCurrencyPipe,
                        IntlCountryPipe,
                        IntlUnitPipe,
                        IntlListPipe,
                    ],
                }]
        }] });

/*
 * Public API Surface of angular-ecmascript-intl
 */

/**
 * Generated bundle index. Do not edit.
 */

export { INTL_COUNTRY_PIPE_DEFAULT_OPTIONS, INTL_CURRENCY_PIPE_DEFAULT_OPTIONS, INTL_DATE_PIPE_DEFAULT_OPTIONS, INTL_DECIMAL_PIPE_DEFAULT_OPTIONS, INTL_LANGUAGE_PIPE_DEFAULT_OPTIONS, INTL_LIST_PIPE_DEFAULT_OPTIONS, INTL_LOCALES, INTL_PERCENT_PIPE_DEFAULT_OPTIONS, INTL_UNIT_PIPE_DEFAULT_OPTIONS, IntlCountryPipe, IntlCurrencyPipe, IntlDatePipe, IntlDecimalPipe, IntlLanguagePipe, IntlListPipe, IntlModule, IntlPercentPipe, IntlUnitPipe };
//# sourceMappingURL=angular-ecmascript-intl.mjs.map
